Summary: Programs for mounting and unmounting filesystems.
Name: mount
Exclusiveos: Linux
Version: 2.11b
Release: 3
Copyright: GPL
Group: System Environment/Base
Source: ftp://ftp.win.tue.nl/pub/linux/utils/util-linux/util-linux-%{version}.tar.bz2
Patch:  mount-2.10r-alphahack.patch
Patch1: mount-2.10m-nolock-docs.patch
Patch2: mount-2.10o-nfsman.patch
Patch3: mount-2.10r-warn.patch
Patch4: mount-2.10r-2gb.patch
Patch5: mount-2.10r-ia64.patch
Patch6: mount-2.10r-kudzu.patch
Patch7: mount-2.10r-swapon.patch
Patch8: mount-2.11b-swapperms.patch
BuildRoot: /var/tmp/%{name}-root
Prereq: mktemp /bin/awk /usr/bin/cmp textutils fileutils

%description
The mount package contains the mount, umount, swapon and swapoff
programs.  Accessible files on your system are arranged in one big
tree or hierarchy.  These files can be spread out over several
devices. The mount command attaches a filesystem on some device to
your system's file tree.  The umount command detaches a filesystem
from the tree.  Swapon and swapoff, respectively, specify and disable
devices and files for paging and swapping.

%package -n losetup
Summary: Programs for setting up and configuring loopback devices.
Group: System Environment/Base

%description -n losetup
Linux supports a special block device called the loop device, which
maps a normal file onto a virtual block device.  This allows for the
file to be used as a "virtual file system" inside another file.
Losetup is used to associate loop devices with regular files or block
devices, to detach loop devices and to query the status of a loop
device.

%prep
%setup -q -c mount-%{version}
cd util-linux-%{version}
%patch0 -p0 -b .alphahack
%patch1 -p1 -b .docbug
%patch2 -p1 -b .nfsman
%patch3 -p1 -b .warn
%patch4 -p1 -b .2gb
%patch5 -p1 -b .ia64
%patch6 -p1 -b .kudzu
%patch7 -p1 -b .swapon
%patch8 -p1 -b .swapperms

%build
cd util-linux-%{version}

CFLAGS="$RPM_OPT_FLAGS" CXXFLAGS="$RPM_OPT_FLAGS" ./configure
perl -pi -e "s/#define util_linux_version.*/#define util_linux_version \\\"mount-%{version}\\\"/" defines.h
cd mount

( cd ../lib; cc $RPM_OPT_FLAGS -c setproctitle.c; cc $RPM_OPT_FLAGS -c xstrncpy.c )

make	LIB=../lib \
	BINDIR=/bin \
	SBINDIR=/sbin \
	MANDIR=%{_mandir} \
	all

%install
cd util-linux-%{version}/mount
rm -rf $RPM_BUILD_ROOT

make	LIB=../lib \
	BINDIR=$RPM_BUILD_ROOT/bin \
	SBINDIR=$RPM_BUILD_ROOT/sbin \
	MAN5DIR=$RPM_BUILD_ROOT%{_mandir}/man5 \
	MAN8DIR=$RPM_BUILD_ROOT%{_mandir}/man8 \
	INSTALLDIR="install -d -m 755" \
	INSTALLSUID="install -s -m 755" \
	INSTALLBIN="install -s -m 755" \
	INSTALLMAN="install -m 644" \
	install

%clean
rm -rf $RPM_BUILD_ROOT

%post
if [ -f /etc/fstab ] ; then
    # add owner mounting capability to appropriate devices
    TMP=$(mktemp /tmp/fstab.XXXXXX)
    if awk '
	($1 ~ /^\/dev\/fd[01]$/ || $2 ~ /^\/mnt\/cdrom$/) &&
        $4 !~ /user/ && $4 !~ /owner/ {
            if (match($4, "^defaults$"))
                printf "%%-23s %%-23s %%-7s %%-15s %%s %%s\n", $1, $2, $3, "owner", $5, $6
            else
                printf "%%-23s %%-23s %%-7s %%-15s %%s %%s\n", $1, $2, $3, "owner," $4, $5, $6
            next
	}
	{print ; next}
    ' /etc/fstab > $TMP ; then
	if ! cmp -s /etc/fstab $TMP ; then 
	    cat $TMP > /etc/fstab
	fi
	rm $TMP
    else
	echo "attempt to edit fstab in mount package failed" 1>&2
    fi
fi

# the seawolf installer had a (bad) bug
for d in `cat /proc/mounts |cut -d" " -f2`; do
    [ "$d" = "/" ] && d=""
    for n in ${d}/SWAP ${d}/SWAP-[0-9]*; do
        [ -f "$n" ] && chmod 0600 $n
    done
done

exit 0

%files
%defattr(-,root,root)
%attr(4755,root,root)	/bin/mount
%attr(4755,root,root)	/bin/umount
/sbin/swapon
/sbin/swapoff
%{_mandir}/man5/fstab.5*
%{_mandir}/man5/nfs.5*
%{_mandir}/man8/mount.8*
%{_mandir}/man8/swapoff.8*
%{_mandir}/man8/swapon.8*
%{_mandir}/man8/umount.8*

%files -n losetup
%defattr(-,root,root)
%{_mandir}/man8/losetup.8*
/sbin/losetup

%changelog
* Mon Apr 30 2001 Bernhard Rosenkraenzer <bero@redhat.com> 2.11b-3
- Fix permissions on swap even if it's not on the / partition

* Thu Apr 26 2001 Michael Fulbright <msf@redhat.com>
- handle case properly in %post if no swap files present

* Tue Apr 24 2001 Erik Troan <ewt@redhat.com>
- Add patch for swap device/swap file permission warnings from ewt
- added code to %post to fix up permissions on automatically generated swap files

* Tue Apr 24 2001 Bernhard Rosenkraenzer <bero@redhat.com> 2.11b-1
- Update to 2.11b

* Thu Mar 22 2001 Erik Troan <ewt@redhat.com>
- added -e option to swapon
- made -a silently skip swap devics that are already enabled

* Tue Mar 13 2001 Preston Brown <pbrown@redhat.com>
- fix build on alpha (need to include errno.h in pivot_root.c)

* Tue Mar 13 2001 Erik Troan <ewt@redhat.com>
- added patch to ignore kudzu option in fstab
- don't use the same RPM_BUILD_DIR as the util-linux package

* Wed Jan 17 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Get rid of misleading swapon warning (Bug #24219)
- Add support for loopback mounts > 2 GB, Patch from Ben
  LaHaise <bcrl@redhat.com>
- Fix build on ia64

* Mon Jan  1 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- 2.10r

* Wed Aug 30 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 2.10o
- fix up man page (Bug #16418)
- handle RPM_OPT_FLAGS correctly

* Sat Aug 05 2000 Erik Troan <ewt@redhat.com>
- added patches to make losetup return useful return codes

* Fri Aug  4 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Add the nolock option to the nfs(5) man page, since it's referenced
  from mount(8)... (Bug #10859)

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Mon Jun 19 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- FHSify

* Wed Jun 07 2000 Erik Troan <ewt@redhat.com>
- update to 2.10m (added memory leaks back in on realpath failure to avoid
  having a separate patch; doesn't really matter)

* Thu Feb 03 2000 Jakub Jelinek <jakub@redhat.com>
- update to 2.10f
- fix issues in the new realpath code, avoid leaking memory

* Tue Feb 01 2000 Cristian Gafton <gafton@redhat.com>
- add two NFSv3 patches from hjl
- man pages are compressed

* Wed Jan  5 2000 Bernhard Rosenkrnzer <bero@redhat.com>
- 2.10d

* Mon Sep 13 1999 Erik Troan <ewt@redhat.com>
- fixed owner patch <blush>

* Thu Sep 09 1999 Michael K. Johnson <johnsonm@redhat.com>
- added owned patch
- add "owner" option to cdrom and floppy devices unless one of the
  options "owner", "noowner", "user", or "nouser" is already set.
  Set the "noowner" option to keep this change from being made in
  the future.

* Fri Jul 16 1999 Jeff Johnson <jbj@redhat.com>
- update to 2.9u.

* Fri Jun 25 1999 Jeff Johnson <jbj@redhat.com>
- update to 2.9s.

* Thu Apr 15 1999 Jeff Johnson <jbj@redhat.com>
- update to 2.9o.

* Fri Mar 26 1999 Bill Nottingham <notting@redhat.com>
- accept ncpfs/smbfs as valid types, not just ncp/smb

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 3)

* Sun Mar 14 1999 Jeff Johnson <jbj@redhat.com>
- rebuild to try and get setuid bits in binary package  -- they're in the
  spec file %attr (#1507).

* Mon Jan 18 1999 Jeff Johnson <jbj@redhat.com>
- rebuild for Raw Hide.
- update to mount-2.9 (from util-linux-2.9)

* Tue Oct 06 1998 Cristian Gafton <gafton@redhat.com>
- accept the fact that sometimes the last line in fstab does not have a \n

* Wed Aug  5 1998 Jeff Johnson <jbj@redhat.com>
- update to 2.8a (from util-linux)

* Fri May 01 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Thu Apr 30 1998 Cristian Gafton <gafton@redhat.com>
- fixed to compile on manhattan

* Wed Apr 08 1998 Erik Troan <ewt@redhat.com>
- updated to mount-2.7l

* Thu Oct 23 1997 Erik Troan <ewt@redhat.com>
- updated for glibc 2.1

* Wed Sep 03 1997 Erik Troan <ewt@redhat.com>
- updated to 2.7f
- added glibc hacks for the Alpha (I don't know why Intel doesn't need them)

* Tue Jun 17 1997 Erik Troan <ewt@redhat.com>
- updated to 2.6h
- built against glibc
